@@ -44,8 +44,10 @@ import svgwrite
 from OMPython import OMCSessionZMQ
 omc = OMCSessionZMQ()
 
-# OpenModelica setup commands
-OMC_SETUP_COMMANDS = ['setCommandLineOptions("-d=nogen,noevalfunc")']
+# OpenModelica setup commands (use old front-end, see #6301)
+OMC_SETUP_COMMANDS = ['setCommandLineOptions("-d=nogen,noevalfunc,-newInst")']
+# use new front-end and nfAPI
+# OMC_SETUP_COMMANDS = ['setCommandLineOptions("-d=nogen,noevalfunc,newInst,nfAPI")']
 
 def classToFileName(cl):
   """
@@ -111,7 +113,7 @@ def ask_omc(question, opt=None, parsed=True):
 
     try:
         if parsed:
-            res = omc.execute(expression)
+            res = omc.sendExpression(expression)
             omc.clearOMParserResult()
         else:
             res = omc.sendExpression(expression, parsed=False)
@@ -455,7 +457,8 @@ def getGraphicsForClass(modelicaClass):
             graphicsObj['origin'] = [float(g[1]), float(g[2])]
             graphicsObj['rotation'] = float(g[3])
             graphicsObj['extent'] = [[float(g[4]), float(g[5])], [float(g[6]), float(g[7])]]
-            if g[9] is not None:
+
+            if not g[9]:
                 graphicsObj['href'] = "data:image;base64,"+g[9].strip('"')
             else:
                 fname = ask_omc('uriToFilename', g[8], parsed=False).strip().strip('"')
@@ -463,7 +466,7 @@ def getGraphicsForClass(modelicaClass):
                     fname = os.path.join(baseDir, g[8].strip('"'))
                 if os.path.exists(fname):
                     with open(fname, "rb") as f_p:
-                        graphicsObj['href'] = "data:image;base64,"+str(base64.b64encode(f_p.read()))
+                        graphicsObj['href'] = "data:image;base64,"+base64.b64encode(f_p.read()).decode()
                 else:
                     logger.error("Could not find bitmap file {0}".format(g[8]))
                     graphicsObj['href'] = g[8].strip('"')
@@ -771,7 +774,6 @@ def getSvgFromGraphics(dwg, graphics, minX, maxY, includeInvisibleText, transfor
                 shape.push(x_12, y_12, x_n, y_n, x_n, y_n)
             else:
                 shape = dwg.polygon([getCoordinates([x, y], graphics, minX, maxY, transformation, coordinateSystem) for (x, y) in graphics['points']])
-            shape.fill('none', opacity=0)
         else:
             logger.error('Not handled: {0}'.format(graphics))
             return None
@@ -808,10 +810,6 @@ def getSvgFromGraphics(dwg, graphics, minX, maxY, includeInvisibleText, transfor
                 x = x0
             else:
                 x = x1
-            if y0 < y1:
-                y = y0
-            else:
-                y = y1
         elif graphics['horizontalAlignment'] == "TextAlignment.Center":
             extra['text_anchor'] = "middle"
         elif graphics['horizontalAlignment'] == "TextAlignment.Right":
@@ -820,11 +818,6 @@ def getSvgFromGraphics(dwg, graphics, minX, maxY, includeInvisibleText, transfor
                 x = x1
             else:
                 x = x0
-            if y0 < y1:
-                y = y1
-            else:
-                y = y0
-
 
         shape = dwg.text(graphics['textString'].replace('%', ''), None, [x], [y], **extra)
 
